/*
 * Copyright (c) 2008
 * Embedded Brains GmbH
 * Obere Lagerstr. 30
 * D-82178 Puchheim
 * Germany
 * rtems@embedded-brains.de
 *
 * The license and distribution terms for this file may be found in the file
 * LICENSE in this distribution or at http://www.rtems.com/license/LICENSE.
 */

package org.rtems.cdt.properties;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.QualifiedName;
import org.eclipse.jface.preference.DirectoryFieldEditor;
import org.eclipse.jface.preference.ComboFieldEditor;
import org.eclipse.jface.preference.FieldEditorPreferencePage;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.jface.preference.PreferenceStore;
import org.eclipse.jface.preference.StringFieldEditor;
import org.eclipse.ui.IWorkbenchPropertyPage;
import org.rtems.cdt.Activator;
import org.rtems.cdt.Constants;

public class PropertyPage extends FieldEditorPreferencePage implements IWorkbenchPropertyPage {
	private IAdaptable mElement;
	
	private IPreferenceStore mStore;
	
	public PropertyPage() {
		super( GRID);
		
		// Get the default values from the workbench preferences
		IPreferenceStore store = Activator.getDefault().getPreferenceStore();
		
		mStore = new PreferenceStore();
		mStore.setDefault( Constants.BASE_PATH_KEY, store.getString( Constants.BASE_PATH_KEY));
		mStore.setDefault( Constants.VERSION_KEY, store.getString( Constants.VERSION_KEY));
		mStore.setDefault( Constants.TARGET_KEY, store.getString( Constants.TARGET_KEY));
		mStore.setDefault( Constants.BSP_PATH_KEY, store.getString( Constants.BSP_PATH_KEY));
		System.out.println( store.getString( Constants.BASE_PATH_KEY));
		System.out.println( store.getString( Constants.VERSION_KEY));
		System.out.println( store.getString( Constants.TARGET_KEY));
		System.out.println( store.getString( Constants.BSP_PATH_KEY));
		setPreferenceStore( mStore);
		
		setDescription( "You can change the RTEMS base installation path, the RTEMS version, the target architecture and the board support package (BSP) installation path.  This affects only the current project.");
	}
	
	protected void createFieldEditors() {
		IProject project = ((IResource) getElement()).getProject();
		
		// Store current values
		try {
			mStore.setValue(
				Constants.BASE_PATH_KEY,
				project.getPersistentProperty(
					new QualifiedName( "", Constants.BASE_PATH_KEY)
				)
			);
		} catch (CoreException e) {
			// TODO
			e.printStackTrace();
		}
		try {
			mStore.setValue(
				Constants.VERSION_KEY,
				project.getPersistentProperty(
					new QualifiedName( "", Constants.VERSION_KEY)
				)
			);
		} catch (CoreException e) {				
			// TODO
			e.printStackTrace();
		}
		try {
			mStore.setValue(
				Constants.TARGET_KEY,
				project.getPersistentProperty(
					new QualifiedName( "", Constants.TARGET_KEY)
				)
			);
		} catch (CoreException e) {				
			// TODO
			e.printStackTrace();
		}
		try {
			mStore.setValue(
				Constants.BSP_PATH_KEY,
				project.getPersistentProperty(
					new QualifiedName( "", Constants.BSP_PATH_KEY)
				)
			);
		} catch (CoreException e) {				
			// TODO
			e.printStackTrace();
		}
		System.out.println("addFields...");
		addField(
				new DirectoryFieldEditor(
					Constants.BASE_PATH_KEY,
					"Base path:",
					getFieldEditorParent()
				)
			);		
			addField(
				new StringFieldEditor(
					Constants.VERSION_KEY,
					"Version:",
					getFieldEditorParent()
				)
			);	
			addField(
				new ComboFieldEditor(
					Constants.TARGET_KEY,
					"Target:",
					Constants.TARGETS,
					getFieldEditorParent()
				)
			);
			addField(
				new DirectoryFieldEditor(
					Constants.BSP_PATH_KEY,
					"BSP path:",
					getFieldEditorParent()
				)
			);
			System.out.println("...done");
	}
	
	public boolean performOk() {
		System.out.println("performOk");
		try {
			IProject project = ((IResource) getElement()).getProject();
			project.setPersistentProperty(
				new QualifiedName(
					"",
					Constants.BASE_PATH_KEY
				),
				mStore.getString( Constants.BASE_PATH_KEY)
			);
			project.setPersistentProperty(
				new QualifiedName(
					"",
					Constants.VERSION_KEY
				),
				mStore.getString( Constants.VERSION_KEY)
			);
			project.setPersistentProperty(
				new QualifiedName(
					"",
					Constants.TARGET_KEY
				),
				mStore.getString( Constants.TARGET_KEY)
			);
			project.setPersistentProperty(
				new QualifiedName(
					"",
					Constants.BSP_PATH_KEY
				),
				mStore.getString( Constants.BSP_PATH_KEY)
			);
		} catch (CoreException e) {
			return false;
		}
		return true;
	}

	public IAdaptable getElement() {
		return mElement;
	}

	public void setElement( IAdaptable element) {
		this.mElement = element;
	}
}